@@ -1,5 +1,6 @@
 import pyaudio
 import numpy
+import logging
 
 class CallbackParams(object):
     def __init__(self):
@@ -87,7 +88,8 @@ class AudioInterface(object):
         hardware_information = HardwareInformation(pya)
 
         available_devices = hardware_information.devices
-        print(self.device_name)
+        #print(self.device_name)
+        logging.debug("Audio Device %s was selected.", self.device_name)
         device = available_devices[self.device_name]
         self.device_idx = device['index']
         self.num_channels = n_ch
